description_pointselect<-function(){
cat("\n")
cat("*** Instructions (please read carefully.) ***                                \n\n")
cat("-------------------------------------------------------------------------------\n")
cat("                     Point Selection for Lambda_z Estimation                   \n")
cat("-------------------------------------------------------------------------------\n")
cat(" This method is about to select data points for lambda_z estimation based on   \n")
cat(" the manual selection from each subject's log(conc.) vs. time plot.          \n\n")
cat(" 1. MS-Windows OS:                                                             \n")
cat("    Please use your mouse to click the data point on the graph to select       \n")
cat("    the data points for linear regression. Once you want to stop selection     \n")
cat("    for each plot, click the 'Stop' menu on the left corner of th plot         \n")
cat("    and click 'Stop locator.' Alternately, you can use click mouse right-      \n")
cat("    button to bring up hidden menu and click 'Stop' to stop selection.       \n\n")
cat(" 2. Linux/Unix (Ubuntu) PC OS:                                                 \n")
cat("    Use your mouse left (1st)-button to select and mouse right (2nd)-button    \n")
cat("    to stop selection.                                                       \n\n")
cat(" 3. Mac OS X:                                                                  \n")
cat("    Use your mouse button to select and hold down the Control key and click    \n")
cat("    (Control-click) to stop selection.                                       \n\n")
cat(" When finishing the current subject and the next subject's plot will show up.  \n")
cat(" Do the same procedures until finishing all subjects.                         \n\n")
cat(" Note: The # of data points should be at least 2's and max. is 6.              \n")
cat("       Please do NOT choose any data point before Tmax.                        \n")
cat("...............................................................................\n")
cat("\n")
alarm();alarm();readline("  Press Enter to proceed...")
}